@@ -13,7 +13,7 @@ from .latex import (
 from .web_search import web_search, tavily_web_search, exa_web_search, brave_web_search
 from .visit_webpage import visit_webpage
 from .bitflip import extract_bitflip_info, generate_research_proposal, score_research_proposals
-from .review import review_pdf
+from .review import review_pdf_paper, download_pdf_paper
 
 __all__ = [
     "arxiv_search",
@@ -35,5 +35,6 @@ __all__ = [
     "extract_bitflip_info",
     "generate_research_proposal",
     "score_research_proposals",
-    "review_pdf",
+    "review_pdf_paper",
+    "download_pdf_paper",
 ]
