@@ -1,10 +1,11 @@
 import base64
 import os
+import uuid
 from io import BytesIO
 from pathlib import Path
 from typing import List, Dict, Any
 
-from academia_mcp.pdf import parse_pdf_file_to_images, parse_pdf_file
+from academia_mcp.pdf import parse_pdf_file_to_images, parse_pdf_file, download_pdf
 from academia_mcp.llm import llm_acall, ChatMessage
 from academia_mcp.files import get_workspace_dir
 
@@ -14,7 +15,6 @@ You are an expert peer reviewer for top CS/ML venues (e.g., NeurIPS/ICML/ACL).
 Your goal is to produce a fair, rigorous, and reproducible review that is maximally useful to authors and area chairs.
 Be specific: cite paper sections/figures/tables when criticizing or praising.
 Use actionable language ("Provide variance across 5 seeds on Dataset X; add leakage control Y").
-Try to be as harsh as possible, but still be fair and constructive.
 
 # Summary
 Briefly summarize the paper and its contributions.
@@ -54,25 +54,27 @@ As the questions above indicates, originality does not necessarily require intro
 Rather, a work that provides novel insights by evaluating existing methods, or demonstrates improved efficiency, fairness, etc. is also equally valuable.
 
 # Scores
-Quality: Based on what you discussed in “Strengths and Weaknesses”, please assign the paper a numerical rating on the following scale to indicate the quality of the work.
+Try to be specific and detailed in your assessment. Try not to set the same score for all the dimensions.
+
+Quality: Based on what you discussed in the “Quality” section, please assign the paper a numerical rating on the following scale to indicate the quality of the work.
 4 = excellent
 3 = good
 2 = fair
 1 = poor
 
-Clarity: Based on what you discussed in “Strengths and Weaknesses”, please assign the paper a numerical rating on the following scale to indicate the clarity of the paper.
+Clarity: Based on what you discussed in the “Clarity” section, please assign the paper a numerical rating on the following scale to indicate the clarity of the paper.
 4 = excellent
 3 = good
 2 = fair
 1 = poor
 
-Significance: Based on what you discussed in “Strengths and Weaknesses”, please assign the paper a numerical rating on the following scale to indicate the significance of the paper.
+Significance: Based on what you discussed in the “Significance” section, please assign the paper a numerical rating on the following scale to indicate the significance of the paper.
 4 = excellent
 3 = good
 2 = fair
 1 = poor
 
-Originality: Based on what you discussed in “Strengths and Weaknesses”, please assign the paper a numerical rating on the following scale to indicate the originality of the paper.
+Originality: Based on what you discussed in the “Originality” section, please assign the paper a numerical rating on the following scale to indicate the originality of the paper.
 4 = excellent
 3 = good
 2 = fair
@@ -117,15 +119,13 @@ Return the result as a JSON object in the following format:
     "summary": "Summary of the paper",
     "strengths_and_weaknesses": {
         "quality": "Quality-related strengths and weaknesses",
+        "quality_score": ...,
         "clarity": "Clarity-related strengths and weaknesses",
+        "clarity_score": ...,
         "significance": "Significance-related strengths and weaknesses",
+        "significance_score": ...,
         "originality": "Originality-related strengths and weaknesses",
-    },
-    "scores": {
-        "quality": ...,
-        "clarity": ...,
-        "significance": ...,
-        "originality": ...,
+        "originality_score": ...,
     },
     "questions": "Questions and suggestions for the authors",
     "limitations": "Limitations of the paper",
@@ -136,12 +136,33 @@ Return the result as a JSON object in the following format:
 """
 
 
-async def review_pdf(pdf_filename: str) -> str:
+def download_pdf_paper(pdf_url: str) -> str:
     """
-    Review a pdf file.
+    Download a pdf file from a url to the workspace directory.
+
+    Returns the path to the downloaded pdf file.
+
+    Args:
+        pdf_url: The url of the pdf file.
+    """
+    if "arxiv.org/pdf" in pdf_url:
+        pdf_filename = pdf_url.split("/")[-1]
+    else:
+        pdf_filename = str(uuid.uuid4())
+    if not pdf_filename.endswith(".pdf"):
+        pdf_filename += ".pdf"
+
+    pdf_path = Path(get_workspace_dir()) / pdf_filename
+    download_pdf(pdf_url, pdf_path)
+    return pdf_filename
+
+
+async def review_pdf_paper(pdf_filename: str) -> str:
+    """
+    Review a pdf file with a paper.
     It parses the pdf file into images and then sends the images to the LLM for review.
     It can detect different issues with the paper formatting.
-    It also returns a proper NeurIPS-stylereview.
+    Returns a proper NeurIPS-style review.
 
     Args:
         pdf_filename: The path to the pdf file.
