@@ -17,16 +17,16 @@ English constituency parsing both with large and limited training data.
 """
 
 
-def test_document_qa_base() -> None:
-    answer = document_qa(
+async def test_document_qa_base() -> None:
+    answer = await document_qa(
         question="What is BLEU on the WMT 2014 English-to-German translation task?",
         document=DOCUMENT1,
     )
     assert "28.4" in answer
 
 
-def test_document_qa_real_question() -> None:
+async def test_document_qa_real_question() -> None:
     questions = "What is the best model for the Russian language according to the role-play benchmark and its final score?"
     document = arxiv_download("2409.06820")
-    answer = document_qa(question=questions, document=document)
+    answer = await document_qa(question=questions, document=document)
     assert "4.62" in answer or "4.68" in answer
