@@ -3,12 +3,12 @@ import json
 from academia_mcp.tools import web_search
 
 
-def test_web_search() -> None:
-    result = web_search("autoregressive models path-star graphs", provider="tavily", limit=20)
+def test_web_search_base() -> None:
+    result = web_search("autoregressive models path-star graphs", limit=20)
     assert "The Mystery of the Pathological" in result
-    assert "The Pitfalls of Next-Token Prediction" in result
     results = json.loads(result)
     assert results
+    assert "score" not in str(results)
 
 
 def test_web_search_exa() -> None:
